##  Deactivating Users
You can deactivate a user by archiving them. To do this, in the Users section of the administration area, select a user by clicking their email address, then click Archive next to Status. This action revokes the user's access to a specific workspace, but the user still has access to other workspaces where their permission is active. If needed, you can invite the user again by using the Invite User option on the user profile menu.
![Deactivating a User by Clicking](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b9c947a441014a430d3771123b8a2_LowRes.png)
Deactivating a User by Clicking "Archive"
##  Deactivating Users
You can deactivate a user by archiving them. In the Users section of the administration area, select a user by clicking their email address, then click Archive next to Status. This revokes access to a specific workspace, but the user still has access to other workspaces where their permission is active. If needed, you can reinvite the user by using the Invite User option on the user profile menu.
If you remove a user from your IdP, they can no longer access any workspaces within the organization’s SSO domain.
